summaryrefslogtreecommitdiff
path: root/src/projManagement/newProject.py
diff options
context:
space:
mode:
authorSunil Shetye2019-06-24 15:39:01 +0530
committerGitHub2019-06-24 15:39:01 +0530
commitca27e1ab9d418bfece063a38629da4dc09281e45 (patch)
treedb4048b7d093d7827b663b2cac98c5c49e37358e /src/projManagement/newProject.py
parenta5effc6fcfb55751cd60a08f9774391ed34ba711 (diff)
parente75167f3e98add3912ff5db300f6f4d2535c5325 (diff)
downloadeSim-ca27e1ab9d418bfece063a38629da4dc09281e45.tar.gz
eSim-ca27e1ab9d418bfece063a38629da4dc09281e45.tar.bz2
eSim-ca27e1ab9d418bfece063a38629da4dc09281e45.zip
Merge pull request #92 from nilshah98/sphinx
Resolves #90
Diffstat (limited to 'src/projManagement/newProject.py')
-rw-r--r--src/projManagement/newProject.py35
1 files changed, 20 insertions, 15 deletions
diff --git a/src/projManagement/newProject.py b/src/projManagement/newProject.py
index c8cd4078..92e90742 100644
--- a/src/projManagement/newProject.py
+++ b/src/projManagement/newProject.py
@@ -22,33 +22,38 @@ from configuration.Appconfig import Appconfig
import os
import json
-"""
-This class is called when User create new Project.
-"""
class NewProjectInfo(QtGui.QWidget):
+ """
+ This class is called when User create new Project.
+ """
def __init__(self):
super(NewProjectInfo, self).__init__()
self.obj_validation = Validation()
self.obj_appconfig = Appconfig()
- """
- This function create Project related directories and files
+ def createProject(self, projName):
+ """
+ This function create Project related directories and files.
+ Before creating also validates using the `Validation` class
- @params
- :projName => name of the project created passed from
- frontEnd/Application new_project()
+ Validation codes
- @return
- :dirs => The directories inside the project folder
- :filelist => The files inside the project folder
- """
+ - VALID
+ - CHECKEXIST
+ - CHECKNAME
+ - NONE
+
+ @params
+ :projName => name of the project created passed from
+ frontEnd/Application new_project()
+
+ @return
+ :dirs => The directories inside the project folder
+ :filelist => The files inside the project folder
- def createProject(self, projName):
- """
- This function create Project related directories and files
"""
# print "Create Project Called"
self.projName = projName